==> doxia-sitetools_1.1.2.orig.tar.gz: doxia-sitetools-1.1.2/doxia-site-renderer/src/test/java/org/apache/maven/doxia/siterenderer/MiscVerifier.java <==
package org.apache.maven.doxia.siterenderer;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import com.gargoylesoftware.htmlunit.html.HtmlApplet;
import com.gargoylesoftware.htmlunit.html.HtmlDivision;
import com.gargoylesoftware.htmlunit.html.HtmlElement;
import com.gargoylesoftware.htmlunit.html.HtmlPage;
import com.gargoylesoftware.htmlunit.html.HtmlParameter;

import java.util.Iterator;


/**
 * 
 *
 * @author ltheussl
 * @version $Id: MiscVerifier.java 732140 2009-01-06 22:01:29Z ltheussl $
 */
public class MiscVerifier
    extends AbstractVerifier
{
    /** {@inheritDoc} */
    public void verify( String file )
            throws Exception
    {
        HtmlPage page = htmlPage( file );
        assertNotNull( page );

        HtmlElement element = page.getHtmlElementById( "contentBox" );
        assertNotNull( element );
        HtmlDivision division = (HtmlDivision) element;
        assertNotNull( division );

        Iterator elementIterator = division.getAllHtmlChildElements();

        // ----------------------------------------------------------------------
        //
        // ----------------------------------------------------------------------

        HtmlApplet applet = (HtmlApplet) elementIterator.next();
        assertEquals( "org.micro.applet.Main", applet.getAttributeValue( "code" ) );
        assertEquals( "micro-applet.jar", applet.getAttributeValue( "archive" ) );

        HtmlParameter param = (HtmlParameter) elementIterator.next();
        assertEquals( "midlet", param.getAttributeValue( "name" ) );
        assertEquals( "org.micro.applet.SimpleDemoMIDlet", param.getAttributeValue( "value" ) );
    }
}

==> doxia-sitetools_1.11.1.orig.tar.gz: doxia-sitetools-1.11.1/doxia-site-renderer/src/test/java/org/apache/maven/doxia/siterenderer/MiscVerifier.java <==
package org.apache.maven.doxia.siterenderer;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import com.gargoylesoftware.htmlunit.html.HtmlDivision;
import com.gargoylesoftware.htmlunit.html.HtmlElement;
import com.gargoylesoftware.htmlunit.html.HtmlPage;
import com.gargoylesoftware.htmlunit.html.HtmlParameter;
import com.gargoylesoftware.htmlunit.html.HtmlUnknownElement;

import java.util.Iterator;


/**
 *
 * @author ltheussl
 */
public class MiscVerifier
    extends AbstractVerifier
{
    /** {@inheritDoc} */
    public void verify( String file )
            throws Exception
    {
        HtmlPage page = htmlPage( file );
        assertNotNull( page );

        HtmlElement element = page.getHtmlElementById( "contentBox" );
        assertNotNull( element );
        HtmlDivision division = (HtmlDivision) element;
        assertNotNull( division );

        Iterator<HtmlElement> elementIterator = division.getHtmlElementDescendants().iterator();

        // ----------------------------------------------------------------------
        //
        // ----------------------------------------------------------------------

        HtmlUnknownElement applet = (HtmlUnknownElement) elementIterator.next();
        assertEquals( "org.micro.applet.Main", applet.getAttribute( "code" ) );
        assertEquals( "micro-applet.jar", applet.getAttribute( "archive" ) );

        HtmlParameter param = (HtmlParameter) elementIterator.next();
        assertEquals( "midlet", param.getAttribute( "name" ) );
        assertEquals( "org.micro.applet.SimpleDemoMIDlet", param.getAttribute( "value" ) );
    }
}
